@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::Logger;
 # ABSTRACT: Role for logger engines
-$Dancer2::Core::Role::Logger::VERSION = '0.156001';
+$Dancer2::Core::Role::Logger::VERSION = '0.157000';
 use Dancer2::Core::Types;
 
 use Moo::Role;
@@ -30,8 +30,9 @@ has auto_encoding_charset => (
 );
 
 has app_name => (
-    is  => 'ro',
-    isa => Str,
+    is      => 'ro',
+    isa     => Str,
+    default => sub {'-'},
 );
 
 has log_format => (
@@ -87,7 +88,7 @@ sub format_message {
             );
         }
         elsif ( $type eq 'h' ) {
-            return $request->header( $block ) || '-';
+            return ( $request && $request->header($block) ) || '-';
         }
         else {
             Carp::carp("{$block}$type not supported");
@@ -116,8 +117,10 @@ sub format_message {
         m => sub {$message},
         f => sub { $stack[1] || '-' },
         l => sub { $stack[2] || '-' },
-        h => sub { $request->remote_host || $request->address || '-' },
-        i => sub { $request->id || '-' },
+        h => sub {
+            ( $request && $request->remote_host || $request->address ) || '-'
+        },
+        i => sub { ( $request && $request->id ) || '-' },
     };
 
     my $char_mapping = sub {
@@ -193,7 +196,7 @@ Dancer2::Core::Role::Logger - Role for logger engines
 
 =head1 VERSION
 
-version 0.156001
+version 0.157000
 
 =head1 DESCRIPTION
 
